@@ -95,7 +95,7 @@ void KAboutApplicationDialog::Private::init(const KAboutData &ad, Options opt)
         titleWidget->setPixmap(QPixmap::fromImage(aboutData.programLogo().value<QImage>()), KTitleWidget::ImageLeft);
     }
 
-    titleWidget->setText(i18n("<html><font size=\"5\">%1</font></html>", aboutData.displayName()));
+    titleWidget->setText(i18n("<html><font size=\"5\">%1</font><br />Version %2</html>", aboutData.displayName(), aboutData.version()));
 
     //Then the tab bar...
     QTabWidget *tabWidget = new QTabWidget;
@@ -150,12 +150,9 @@ void KAboutApplicationDialog::Private::init(const KAboutData &ad, Options opt)
     // Version
     QWidget *versionWidget = new QWidget(q);
     QVBoxLayout *versionLayout = new QVBoxLayout;
-    QLabel *versionLabel = new QLabel(i18n("<b>Version %1</b>", aboutData.version()));
-    versionLabel->setTextInteractionFlags(Qt::TextSelectableByMouse);
-    versionLayout->addWidget(versionLabel);
     if (!(opt & HideKdeVersion)) {
         QLabel *versionLabel = new QLabel(
-            i18n("Using:<ul><li>KDE Frameworks %1</li><li>Qt %2 (built against %3)</li><li>The <em>%4</em> windowing system</li></ul>",
+            i18n("<ul><li>KDE Frameworks %1</li><li>Qt %2 (built against %3)</li><li>The <em>%4</em> windowing system</li></ul>",
                  QStringLiteral(KXMLGUI_VERSION_STRING),
                  QString::fromLocal8Bit(qVersion()),
                  QStringLiteral(QT_VERSION_STR),
@@ -165,7 +162,7 @@ void KAboutApplicationDialog::Private::init(const KAboutData &ad, Options opt)
     }
     versionLayout->addStretch();
     versionWidget->setLayout(versionLayout);
-    tabWidget->addTab(versionWidget, i18n("&Version"));
+    tabWidget->addTab(versionWidget, i18n("&Libraries"));
 
     //Palette needed at least for translators...
     QPalette transparentBackgroundPalette;
@@ -184,18 +181,16 @@ void KAboutApplicationDialog::Private::init(const KAboutData &ad, Options opt)
             bugsLabel->setContentsMargins(4, 2, 0, 4);
             bugsLabel->setOpenExternalLinks(true);
             if (!aboutData.customAuthorTextEnabled()) {
-                if (aboutData.bugAddress().isEmpty() || aboutData.bugAddress() == QLatin1String("submit@bugs.kde.org")) {
+                const QString bugAddress = aboutData.bugAddress();
+                if (bugAddress.isEmpty() || bugAddress == QLatin1String("submit@bugs.kde.org")) {
                     bugsLabel->setText(i18n("Please use <a href=\"http://bugs.kde.org\">http://bugs.kde.org</a> to report bugs.\n"));
                 } else {
-                    if ((aboutData.authors().count() == 1) &&
-                            (aboutData.authors().first().emailAddress() == aboutData.bugAddress())) {
-                        bugsLabel->setText(i18n("Please report bugs to <a href=\"mailto:%1\">%2</a>.\n",
-                                                aboutData.authors().first().emailAddress(),
-                                                aboutData.authors().first().emailAddress()));
-                    } else {
-                        bugsLabel->setText(i18n("Please report bugs to <a href=\"mailto:%1\">%2</a>.\n",
-                                                aboutData.bugAddress(), aboutData.bugAddress()));
+                    QUrl bugUrl(bugAddress);
+                    if (bugUrl.scheme().isEmpty()) {
+                        bugUrl.setScheme(QLatin1String("mailto"));
                     }
+                    bugsLabel->setText(i18n("Please report bugs to <a href=\"%1\">%2</a>.\n",
+                                            bugUrl.toString(), bugAddress));
                 }
             } else {
                 bugsLabel->setText(aboutData.customAuthorRichText());
@@ -345,7 +340,7 @@ void KAboutApplicationDialog::Private::_k_showLicense(const QString &number)
     // try to allow enough height for a reasonable number of lines to be shown
     const int idealHeight = metrics.height() * 30;
 
-    dialog->resize(dialog->sizeHint().expandedTo(QSize((int)idealWidth, idealHeight)));
+    dialog->resize(dialog->sizeHint().expandedTo(QSize(qRound(idealWidth), idealHeight)));
     dialog->adjustSize();
     dialog->show();
 }
