@@ -29,7 +29,8 @@
 #include <kxmlgui_export.h>
 #include <kstandardaction.h>
 
-#include <QtCore/QObject>
+#include <QObject>
+#include <QAction>
 
 class QAction;
 class KXMLGUIClient;
@@ -147,7 +148,7 @@ public:
       * application's configuration file KSharedConfig::openConfig(),
       * in the group set by setConfigGroup().
       */
-    void readSettings(KConfigGroup *config = 0);
+    void readSettings(KConfigGroup *config = nullptr);
 
     /**
       * Import from @p config all configurable global key associations.
@@ -183,7 +184,7 @@ public:
       * \param oneAction pass an action here if you just want to save the values for one action, eg.
       *                  if you know that action is the only one which has changed.
       */
-    void writeSettings(KConfigGroup *config = 0, bool writeDefaults = false, QAction *oneAction = 0) const;
+    void writeSettings(KConfigGroup *config = nullptr, bool writeDefaults = false, QAction *oneAction = nullptr) const;
 
     /**
      * Returns the number of actions in the collection.
@@ -237,8 +238,9 @@ public:
      * \warning Don't call this method on a KActionCollection that contains
      * actions. This is not supported.
      *
-     * \param componentData the KComponentName which is to be associated with this action collection,
-     * or QString() to indicate the app name.
+     * \param componentData the name which is to be associated with this action collection,
+     * or QString() to indicate the app name. This is used to load/save settings into XML files.
+     * KXmlGuiClient::setComponentName takes care of calling this.
      */
     void setComponentName(const QString &componentName);
 
@@ -248,6 +250,7 @@ public:
     /**
      * Set the component display name associated with this action collection.
      * (e.g. for the toolbar editor)
+     * KXmlGuiClient::setComponentName takes care of calling this.
      */
     void setComponentDisplayName(const QString &displayName);
 
@@ -289,7 +292,7 @@ Q_SIGNALS:
 
 protected:
     /// Overridden to perform connections when someone wants to know whether an action was highlighted or triggered
-    virtual void connectNotify(const QMetaMethod &signal);
+    void connectNotify(const QMetaMethod &signal) Q_DECL_OVERRIDE;
 
 protected Q_SLOTS:
     virtual void slotActionTriggered();
@@ -314,7 +317,7 @@ public:
      * Inserting an action under a name that is already used for another action will replace
      * the other action in the collection (but will not delete it).
      *
-     * If KAuthorized::authorizeKAction() reports that the action is not
+     * If KAuthorized::authorizeAction() reports that the action is not
      * authorized, it will be disabled and hidden.
      *
      * @param name The name by which the action be retrieved again from the collection.
@@ -363,13 +366,13 @@ public:
      * KStandardAction::stdName.
      *
      * @param actionType The standard action type of the action to create.
-     * @param receiver The QObject to connect the triggered(bool) signal to.  Leave 0 if no
+     * @param receiver The QObject to connect the triggered(bool) signal to.  Leave nullptr if no
      *                 connection is desired.
-     * @param member The SLOT to connect the triggered(bool) signal to.  Leave 0 if no
+     * @param member The SLOT to connect the triggered(bool) signal to.  Leave nullptr if no
      *               connection is desired.
      * @return new action of the given type ActionType.
      */
-    QAction *addAction(KStandardAction::StandardAction actionType, const QObject *receiver = 0, const char *member = 0);
+    QAction *addAction(KStandardAction::StandardAction actionType, const QObject *receiver = nullptr, const char *member = nullptr);
 
     /**
      * Creates a new standard action, adds to the collection under the given name
@@ -383,14 +386,14 @@ public:
      *
      * @param actionType The standard action type of the action to create.
      * @param name The name by which the action be retrieved again from the collection.
-     * @param receiver The QObject to connect the triggered(bool) signal to.  Leave 0 if no
+     * @param receiver The QObject to connect the triggered(bool) signal to.  Leave nullptr if no
      *                 connection is desired.
-     * @param member The SLOT to connect the triggered(bool) signal to.  Leave 0 if no
+     * @param member The SLOT to connect the triggered(bool) signal to.  Leave nullptr if no
      *               connection is desired.
      * @return new action of the given type ActionType.
      */
     QAction *addAction(KStandardAction::StandardAction actionType, const QString &name,
-                       const QObject *receiver = 0, const char *member = 0);
+                       const QObject *receiver = nullptr, const char *member = nullptr);
 
     /**
      * Creates a new action under the given name to the collection and connects
@@ -408,13 +411,13 @@ public:
      * the other action in the collection.
      *
      * @param name The name by which the action be retrieved again from the collection.
-     * @param receiver The QObject to connect the triggered(bool) signal to.  Leave 0 if no
+     * @param receiver The QObject to connect the triggered(bool) signal to.  Leave nullptr if no
      *                 connection is desired.
-     * @param member The SLOT to connect the triggered(bool) signal to.  Leave 0 if no
+     * @param member The SLOT to connect the triggered(bool) signal to.  Leave nullptr if no
      *               connection is desired.
      * @return new action of the given type ActionType.
      */
-    QAction *addAction(const QString &name, const QObject *receiver = 0, const char *member = 0);
+    QAction *addAction(const QString &name, const QObject *receiver = nullptr, const char *member = nullptr);
 
     /**
      * Creates a new action under the given name, adds it to the collection and connects the action's triggered(bool)
@@ -426,16 +429,16 @@ public:
      * signal.
      *
      * @param name The internal name of the action (e.g. "file-open").
-     * @param receiver The QObject to connect the triggered(bool) signal to.  Leave 0 if no
+     * @param receiver The QObject to connect the triggered(bool) signal to.  Leave nullptr if no
      *                 connection is desired.
-     * @param member The SLOT to connect the triggered(bool) signal to.  Leave 0 if no
+     * @param member The SLOT to connect the triggered(bool) signal to.  Leave nullptr if no
      *               connection is desired.
      * @return new action of the given type ActionType.
      *
      * @see addAction()
      */
     template<class ActionType>
-    ActionType *add(const QString &name, const QObject *receiver = 0, const char *member = 0)
+    ActionType *add(const QString &name, const QObject *receiver = nullptr, const char *member = nullptr)
     {
         ActionType *a = new ActionType(this);
         if (receiver && member) {
@@ -445,6 +448,47 @@ public:
         return a;
     }
 
+    /**
+     * This is the same as add(const QString &name, const QObject *receiver, const char *member) using
+     * new style connect syntax.
+     *
+     * @param name The internal name of the action (e.g. "file-open").
+     * @param receiver The QObject to connect the triggered(bool) signal to.
+     * @param slot The slot or lambda to connect the triggered(bool) signal to.
+     * @return new action of the given type ActionType.
+     *
+     * @see add(const QString &, const QObject *, const char *)
+     * @since 5.28
+     */
+    template<class ActionType, class Receiver, class Func>
+    inline typename std::enable_if<!std::is_convertible<Func, const char*>::value, ActionType>::type *add(
+        const QString &name, const Receiver *receiver, Func slot)
+    {
+        ActionType *a = new ActionType(this);
+        connect(a, &QAction::triggered, receiver, slot);
+        addAction(name, a);
+        return a;
+    }
+
+    /**
+     * This is the same as addAction(const QString &name, const QObject *receiver, const char *member) using
+     * new style connect syntax.
+     *
+     * @param name The internal name of the action (e.g. "file-open").
+     * @param receiver The QObject to connect the triggered(bool) signal to.
+     * @param slot The slot or lambda to connect the triggered(bool) signal to.
+     * @return new action of the given type ActionType.
+     *
+     * @see addAction(const QString &, const QObject *, const char *)
+     * @since 5.28
+     */
+    template<class Receiver, class Func>
+    inline typename std::enable_if<!std::is_convertible<Func, const char*>::value, QAction>::type *addAction(
+        const QString &name, const Receiver *receiver, Func slot)
+    {
+        return add<QAction>(name, receiver, slot);
+    }
+
     /**
      * Get the default primary shortcut for the given action.
      *
@@ -484,7 +528,7 @@ public:
      * @param shortcuts the shortcuts to use for the given action in its specified shortcutContext()
      * @since 5.0
      */
-    void setDefaultShortcuts(QAction *action, const QList<QKeySequence> &shortcuts);
+    Q_INVOKABLE void setDefaultShortcuts(QAction *action, const QList<QKeySequence> &shortcuts);
 
     /**
      * Returns true if the given action's shortcuts may be configured by the user.
