@@ -37,13 +37,13 @@ namespace
 const char actionListName[] = "show_menu_and_toolbar_actionlist";
 
 const char guiDescription[] = ""
-                             "<!DOCTYPE kpartgui><kpartgui name=\"StandardToolBarMenuHandler\">"
+                             "<!DOCTYPE gui><gui name=\"StandardToolBarMenuHandler\">"
                              "<MenuBar>"
                              "    <Menu name=\"settings\">"
                              "        <ActionList name=\"%1\" />"
                              "    </Menu>"
                              "</MenuBar>"
-                             "</kpartgui>";
+                             "</gui>";
 
 class BarActionBuilder
 {
@@ -260,7 +260,7 @@ void ToolBarHandler::setupActions()
     // We have no XML file associated with our action collection, so load settings from KConfig
     actionCollection()->readSettings(); // #233712
 
-    if (KAuthorized::authorizeKAction(QStringLiteral("options_show_toolbar"))) {
+    if (KAuthorized::authorizeAction(QStringLiteral("options_show_toolbar"))) {
         plugActionList(QLatin1String(actionListName), d->actions);
     }
 
